function y = embedWithDelta(x, lags)
% [mix] = gmmemTrain(covartype,kmix,trainDataM,options)
%
% Input Variables
%       x - scalar time series
%       lags - vector of lags
%
% Output Variables
%       y - phase space with first difference appended
%
% Language - MATLAB
%  
% Description:
% this version of embed takes in a scalar time series and embeds in a phase space normally and also includes additional
% the delta vectors producing a 2*m dimensional phase space where the first m dimensions are the orginal phase space
% and the remaining m dimensions are difference between those vectors so that trajectory information is incorporated

%
% Created:     
%               Date: 5/14/2003
%               By:  Andrew Lindgren
%               Marquette University


x = embed(x,lags)';     % embed the data as normally do
m = length(lags) +1;    % number of dimensions in the orginal phase space
s = size(x):            % size of array   
y = x;                  % copy to new matrix

% lines of code replicate to create full window on the top and bottom
x = [x(1,:); x(1,:); x; x(s(2),:); x(s(2),:)];

%does the linear regression to get the deltas
for i = 1:s(2)  
     y(i, m+1:2*m) = ((x(i+3,:) - x(i+1,:)) + 2*(x(i+4,:)-x(i,:)))/10; %computes the deltas over each window
end
 
    


